profile ukfs_2x_12_r {

	Sample template for DynaTrax testing
	Copyright  Trainsimfiles.com

	header {
		#regid may be used for ensuring profiles are approved/registered
		regid=ukfs_1x.trainsimfiles.uk

		#profileSet is the track system the profile belongs to
		profileSet=UK FineScale

		#profileName is a description of the profile
		profilename=UK FineScale Standard Gauge (2x_12 raised sleeper)

		#url/email for profile issues
		support=http://support.trainsimfiles.com/

		#gauge value, only to be used later for selecting profiles by gauge instead of track set
		gauge=1.435
	}

	#note: all lengths/distances and point coordinates are in metres, angles are degrees, and 
	
	#segmentation parameters sets how segmentation of shapes is to occur
	#by setting a maximum segment angle, and minimum plus maximum segment lengths 
	#these allow the track to be segmented according to the track developers desired quality
	
	#the segment angle is used on curves to set the maximum segmentation angle
	#lower values = smoother curves = more polygons
	maxSegAngle=0.75

	#this avoids very sharp curves from using large numbers of polygons 
	minSegLength=1.0

	#maxSegLength sets the maximum polygon length a value <20m is recommended so when lit at night by headlamps 
	#the surface is evenly lit (avoids pulsating surfaces).
	maxSegLength=12.5

	#List of materials to be used for the shape
	#materials: name (filename,mip bias,shader,filter,lighting,alphamode,zbuffer,u_scale,v_scale)
	#u_scale and v_scale are in metres and are the physical distances the texture covers (ie. length / u_scale = u )
	#note: some parameters are based on GMAX materials form
	#eg. zbuffer=test, this makes shadows appear on that surface
	material=BALLAST (ukfs_track1.ace,0,BlendATexDiff,LinearMipLinear,OptSpecular0,none,test,0,6.096)
	material=SLEEPERS (ukfs_sleepers.ace,0,BlendATexDiff,LinearMipLinear,OptSpecular0,none,normal,0,6.096)
	material=RAILSIDES (ukfs_rail.ace,-2,TexDiff,LinearMipLinear,OptSpecular0,none,normal,18,0)
	material=RAILTOPS (ukfs_rail.ace,-1,TexDiff,LinearMipLinear,OptSpecular25,none,normal,18,0)
	material=RAILCHAIRS (ukfs_track1.ace,-2,BlendATexDiff,LinearMipLinear,OptSpecular0,trans,normal,0,6.096)

	#List of unique points that describe the shape - this avoids having to repeat coordinates in profile lines later on
	points=(-4.9161,0.06,0)(-3.9161,0.11,0)(-1.3257,0.11,0)(-0.3257,0.06,0)
	points=(-3.9161,0.122,0)(-1.3257,0.122,0)
	points=(-3.3384,0.3,0)(-3.3384,0.15,0)(-3.4134,0.15,0)(-3.4134,0.3,0)
	points=(-1.8284,0.3,0)(-1.8284,0.15,0)(-1.9034,0.15,0)(-1.9034,0.3,0)
	points=(-3.5034,0.11,0)(-3.4134,0.2,0)(-3.3384,0.2,0,0)(-3.2484,0.11,0)
	points=(-1.9934,0.11,0)(-1.9034,0.2,0,0)(-1.8284,0.2,0)(-1.7384,0.11,0)
	points=(-4.9161,0.11,0)(-0.3257,0.11,0)

	points=(0.3257,0.06,0)(1.3257,0.11,0)(3.9161,0.11,0)(4.9161,0.06,0)
	points=(1.3257,0.122,0)(3.9161,0.122,0)
	points=(1.9034,0.3,0)(1.9034,0.15,0)(1.8284,0.15,0)(1.8284,0.3,0)
	points=(3.4134,0.3,0)(3.4134,0.15,0)(3.3384,0.15,0)(3.3384,0.3,0)
	points=(1.7384,0.11,0)(1.8284,0.2,0)(1.9034,0.2,0,0)(1.9934,0.11,0)
	points=(3.2484,0.11,0)(3.3384,0.2,0,0)(3.4134,0.2,0)(3.5034,0.11,0)
	points=(0.3257,0.11,0)(4.9161,0.11,0)

	#List of UV mapping points for tiling: 0,0 is bottom left of texture
	uvpoints=(0.246,0)(0.412,0)(0.834,0)(0.998,0)
	uvpoints=(0,0.977)(0,0.949)
	uvpoints=(0,0.998)(0,0.979)
	uvpoints=(0,0)(0.02,0)(0.040,0)
	uvpoints=(0.898,0)(0.345,0)

	#set number of LOD levels and distances
	#note: half shape length is added to first LOD distance automatically
	lods=50,400,1000,2000
	
	#degrade values for each lod level; divides the number of segments to be generated by this value
	# a value of 1 leaves the segmentation as determined by segmentation values above
	degrade=1,2,4,8

	#'list of distinct objects, each object can have 1 material only - though objects can share materials
	#any number of objects may be added, though for performance reasons the fewer the better
	#multi-material objects not yet supported

	#'currently must be in order of LOD and subobject.

	object BASE {
		#subobject is used for alpha sorting purposes, though not really require for track
		#a value of 1 is used for UKFS shapes to force sleepers to overwrite the trackbed (avoids sleeper/ballast contention)
		subobject=0

		#the material use for this object, from the list above
		materialName=BALLAST

		#profile=lod level, (point number,uv number),( ... )
		#point and uv numbers are from the list above, starting at 0
		#all points on one profile line will be welded, for smooth continous surfaces
		#use a profile line to start a new surface
		profile=0,(0,0)(1,1)(2,2)(3,3)
		profile=0,(24,0)(25,1)(26,2)(27,3)
		profile=1,(0,0)(1,1)(2,2)(3,3)
		profile=1,(24,0)(25,1)(26,2)(27,3)
		profile=2,(22,0)(23,11)
		profile=2,(46,12)(47,3)
		profile=3,(22,0)(23,11)
		profile=3,(46,12)(47,3)
	}
	object RAILS {
		subobject=0
		materialName=RAILSIDES
		profile=0,(6,4)(7,5)
		profile=0,(8,5)(9,4)
		profile=0,(10,4)(11,5)
		profile=0,(12,5)(13,4)
		profile=0,(30,4)(31,5)
		profile=0,(32,5)(33,4)
		profile=0,(34,4)(35,5)
		profile=0,(36,5)(37,4)
		profile=1,(6,4)(7,5)
		profile=1,(8,5)(9,4)
		profile=1,(10,4)(11,5)
		profile=1,(12,5)(13,4)
		profile=1,(30,4)(31,5)
		profile=1,(32,5)(33,4)
		profile=1,(34,4)(35,5)
		profile=1,(36,5)(37,4)
		profile=2,(6,4)(7,5)
		profile=2,(8,5)(9,4)
		profile=2,(10,4)(11,5)
		profile=2,(12,5)(13,4)
		profile=2,(30,4)(31,5)
		profile=2,(32,5)(33,4)
		profile=2,(34,4)(35,5)
		profile=2,(36,5)(37,4)
	}
	object RAILTOPS {
		subobject=0
		materialName=RAILTOPS
		profile=0,(9,6)(6,7)
		profile=0,(13,6)(10,7)
		profile=0,(33,6)(30,7)
		profile=0,(37,6)(34,7)
		profile=1,(9,6)(6,7)
		profile=1,(13,6)(10,7)
		profile=1,(33,6)(30,7)
		profile=1,(37,6)(34,7)
		profile=2,(9,6)(6,7)
		profile=2,(13,6)(10,7)
		profile=2,(33,6)(30,7)
		profile=2,(37,6)(34,7)
	}
	object RAILCHAIRS {
		subobject=0
		materialName=RAILCHAIRS
		profile=0,(14,8)(15,9)
		profile=0,(16,9)(17,10)
		profile=0,(18,10)(19,9)
		profile=0,(20,9)(21,8)
		profile=0,(38,8)(39,9)
		profile=0,(40,9)(41,10)
		profile=0,(42,10)(43,9)
		profile=0,(44,9)(45,8)
	}
	object SLEEPERS {
		subobject=1
		materialName=SLEEPERS
		profile=0,(4,1)(5,2)
		profile=0,(28,1)(29,2)
		profile=1,(4,1)(5,2)
		profile=1,(28,1)(29,2)
		profile=2,(4,1)(5,2)
		profile=2,(28,1)(29,2)
	}
}